@@ -3,7 +3,7 @@ from typing import Union
 from ...exceptions import EvaluationNotRelevant
 from ...transport import TLSTransport
 from ...certificate import BaseCertificate, LeafCertificate
-from ...util import key_usage_exists
+from ...util import key_usage_exists, gather_key_usages
 from .. import BaseEvaluationTask
 
 
@@ -16,6 +16,11 @@ class EvaluationTask(BaseEvaluationTask):
     def evaluate(self, certificate: BaseCertificate) -> Union[bool, None]:
         if not isinstance(certificate, LeafCertificate):
             raise EvaluationNotRelevant
+        validator_key_usage, validator_extended_key_usage = gather_key_usages(
+            certificate.x509.to_cryptography()
+        )
+        self.substitution_metadata["key_usage"] = validator_key_usage
+        self.substitution_metadata["extended_key_usage"] = validator_extended_key_usage
         return (
             key_usage_exists(certificate.x509.to_cryptography(), "digital_signature")
             and key_usage_exists(certificate.x509.to_cryptography(), "serverAuth")
